/* Copyright 2010 ESRI
* 
* All rights reserved under the copyright laws of the United States
* and applicable international laws, treaties, and conventions.
* 
* You may freely redistribute and use this sample code, with or
* without modification, provided you include the original copyright
* notice and use restrictions.
* 
* See the use restrictions at http://help.arcgis.com/en/sdk/10.0/usageRestrictions.htm
* 
*/
package arcgissamples.trackinganalyst;

import java.awt.BorderLayout;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.io.File;
import java.io.IOException;

import javax.swing.JFrame;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.SwingUtilities;

import arcgissamples.trackinganalyst.command.DisplayDataCommand;

import com.esri.arcgis.beans.TOC.TOCBean;
import com.esri.arcgis.beans.map.MapBean;
import com.esri.arcgis.beans.toolbar.ToolbarBean;
import com.esri.arcgis.controls.ControlsMapFullExtentCommand;
import com.esri.arcgis.controls.ControlsMapPanTool;
import com.esri.arcgis.controls.ControlsMapZoomInTool;
import com.esri.arcgis.controls.ControlsMapZoomOutTool;
import com.esri.arcgis.interop.AutomationException;
import com.esri.arcgis.system.AoInitialize;
import com.esri.arcgis.system.EngineInitializer;
import com.esri.arcgis.system.esriLicenseProductCode;
import com.esri.arcgis.system.esriLicenseStatus;
import com.esri.arcgis.systemUI.esriCommandStyles;

public class DisplayTemporalData extends JFrame
{
	private static AoInitialize aoInit = null;
	static String devKitHome = "";
	
	public DisplayTemporalData()
	{
		addWindowListener(new WindowAdapter()
		{
			public void windowClosing(WindowEvent e)
			{
				try
				{
					// Release license
					aoInit.shutdown();

					// Do not make any call to ArcObjects after ShutDownApplication()
					EngineInitializer.releaseAll();

					System.exit(0);
				}
				catch (AutomationException e1)
				{
					e1.printStackTrace();
				}
				catch (IOException e1)
				{
					e1.printStackTrace();
				}
			}
		});

	}

	public static void main(String[] args)
	{
		System.out.println("Starting DisplayTemporalData - An ArcObjects Java SDK Developer Sample");

		try
		{
			EngineInitializer.initializeVisualBeans();
			aoInit = new AoInitialize();

			final DisplayTemporalData dataDisplayer = new DisplayTemporalData();
			dataDisplayer.initializeArcGISLicenses();

			SwingUtilities.invokeLater(new Runnable()
			{
				public void run()
				{
					try
					{
						devKitHome = System.getenv("AGSDEVKITJAVA");
						if (devKitHome == null || devKitHome.equalsIgnoreCase(""))
						{
							System.out.println("ERROR - ArcGIS Developer Kit home invalid. Exiting application...");
							System.exit(-1);
						}
						dataDisplayer.buildAppFrame();
						dataDisplayer.setVisible(true);

					}
					catch (Exception e)
					{
						e.printStackTrace();
					}
				}
			});
		}
		catch (Exception e)
		{
			e.printStackTrace();
		}
	}

	/*
	 * Build the application frame with Engine Controls and Swing Components
	 */
	private void buildAppFrame() throws Exception
	{
		this.setSize(800, 600);
		this.setTitle("Tracking Analyst Display Temporal Data");
		setContentPane(getJContentPane());
		this.setVisible(true);

		setDefaultCloseOperation(DisplayTemporalData.DISPOSE_ON_CLOSE);
	}

	/*
	 * Initializes ContentPane
	 */
	private JPanel getJContentPane() throws Exception
	{
		JPanel contentPane = new JPanel();
		contentPane.setLayout(new BorderLayout());

		// Initialize ToolbarBean
		ToolbarBean toolbarBean = new ToolbarBean();

		// Fixed zoom in command to toolbar
		toolbarBean.addItem(new ControlsMapZoomInTool(), 0, -1, false, 0, esriCommandStyles.esriCommandStyleIconOnly);

		// Fixed zoom out command to toolbar
		toolbarBean.addItem(new ControlsMapZoomOutTool(), 0, -1, false, 0, esriCommandStyles.esriCommandStyleIconOnly);

		// Globe Zoom in-out command to toolbar
		toolbarBean.addItem(new ControlsMapPanTool(), 0, -1, false, 0, esriCommandStyles.esriCommandStyleIconOnly);

		// Pan Drag command to toolbar
		toolbarBean.addItem(new ControlsMapFullExtentCommand(), 0, -1, false, 0,
				esriCommandStyles.esriCommandStyleIconOnly);

		// Add Playback Command (defined in PlaybackCommand.java)
		toolbarBean.addItem(new DisplayDataCommand(this, devKitHome), 0, -1, false, 0, esriCommandStyles.esriCommandStyleTextOnly);

		// Initialize map and toc beans
		MapBean mapBean = new MapBean();
		// add mapbean as buddy control to toolbar
		toolbarBean.setBuddyControl(mapBean);

		// initialize toc bean
		TOCBean tocBean = new TOCBean();
		// add mapbean as buddy control to toc bean
		tocBean.setBuddyControl(mapBean);

		// add toolbar, toc and map beans to contentPane
		contentPane.add(toolbarBean, BorderLayout.NORTH);
		contentPane.add(tocBean, BorderLayout.WEST);
		contentPane.add(mapBean, BorderLayout.CENTER);

		return contentPane;
	}

	/**
	 * Initializes the lowest available ArcGIS License
	 */
	private void initializeArcGISLicenses()
	{
		try
		{
			if (aoInit.isProductCodeAvailable(esriLicenseProductCode.esriLicenseProductCodeEngine) == esriLicenseStatus.esriLicenseAvailable)
			{
				aoInit.initialize(esriLicenseProductCode.esriLicenseProductCodeEngine);
			}
			else if (aoInit.isProductCodeAvailable(esriLicenseProductCode.esriLicenseProductCodeArcView) == esriLicenseStatus.esriLicenseAvailable)
			{
				aoInit.initialize(esriLicenseProductCode.esriLicenseProductCodeArcView);
			}
			else
			{
				System.err.println("Could not initialize an Engine or ArcView license. Exiting application.");
				System.exit(-1);
			}

			aoInit.checkOutExtension(com.esri.arcgis.system.esriLicenseExtensionCode.esriLicenseExtensionCodeTracking);
		}
		catch (Exception e)
		{
			e.printStackTrace();
		}
	}

	/**
	 * Returns output directory
	 * 
	 * @return
	 */
	private static String getOutputDir()
	{
		String userDir;
		if (System.getProperty("os.name").toLowerCase().indexOf("win") > -1)
			userDir = System.getenv("UserProfile");
		else
			userDir = System.getenv("HOME");
		String outputDir = userDir + File.separator + "arcgis_sample_output";
		System.out.println("Creating output directory - " + outputDir);
		new File(outputDir).mkdir();
		return outputDir;

	}

}
